@@ -2,7 +2,7 @@
 #
 #       exports.py
 #
-#       Copyright 2009-2016 Giuseppe Penone <giuspen@gmail.com>
+#       Copyright 2009-2017 Giuseppe Penone <giuspen@gmail.com>
 #
 #       This program is free software; you can redistribute it and/or modify
 #       it under the terms of the GNU General Public License as published by
@@ -19,9 +19,28 @@
 #       Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 #       MA 02110-1301, USA.
 
-import os, cgi, base64, shutil, copy
+import os
+import cgi
+import base64
+import shutil
+import copy
 import pango
-import cons, support
+import cons
+import support
+
+
+def rgb_str_from_int24bit(int24bit):
+    r = (int24bit >> 16) & 0xff
+    g = (int24bit >> 8) & 0xff
+    b = int24bit & 0xff
+    return "#%.2x%.2x%.2x" % (r, g, b)
+
+def rgb_int24bit_from_str(rgb_str):
+    rgb_24 = rgb_any_to_24(rgb_str)
+    r = int(rgb_24[:2], 16)
+    g = int(rgb_24[2:4], 16)
+    b = int(rgb_24[4:], 16)
+    return (r << 16 | g << 8 | b)
 
 def rgb_any_to_24(rgb_in):
     """Convert any RGB to RRGGBB if needed"""
@@ -38,6 +57,22 @@ def rgb_any_to_24(rgb_in):
     print "! rgb_any_to_24(%s)" % rgb_in
     return rgb_in
 
+def rgb_get_is_blackish_or_whiteish(in_rgb):
+    rgb_24 = rgb_any_to_24(in_rgb if not in_rgb.startswith("#") else in_rgb[1:])
+    r = int(rgb_24[:2], 16)
+    g = int(rgb_24[2:4], 16)
+    b = int(rgb_24[4:], 16)
+    # r+g+b black is 0
+    # r+g+b white is 3*255 = 765
+    sum_r_g_b = r+g+b
+    if sum_r_g_b < 150:
+        #print "black-ish", sum_r_g_b
+        return True
+    if sum_r_g_b > 700:
+        #print "white-ish", sum_r_g_b
+        return True
+    return False
+
 def rgb_24_get_is_dark(in_rgb_24):
     r = int(in_rgb_24[:2], 16)
     g = int(in_rgb_24[2:4], 16)
@@ -92,6 +127,18 @@ def clean_text_to_utf8(in_text):
         except: clean_text = clean_text[1:]
     return clean_text
 
+def prepare_export_folder(dir_place, new_folder, overwrite_existing):
+    if os.path.exists(os.path.join(dir_place, new_folder)):
+        if overwrite_existing:
+            shutil.rmtree(os.path.join(dir_place, new_folder))
+        else:
+            n = 2
+            while os.path.exists(os.path.join(dir_place, new_folder + '%03d' % n)):
+                n += 1
+            new_folder += '%03d' % n
+    return new_folder
+
+
 class Export2CTD:
     """The Export to CTD Class"""
 
@@ -165,11 +212,11 @@ class ExportPrint:
         ret_filepath = support.dialog_file_save_as(proposed_name + ".pdf",
             filter_pattern="*.pdf",
             filter_name=_("PDF File"),
-            curr_folder=self.dad.pick_dir,
+            curr_folder=self.dad.pick_dir_export,
             parent=self.dad.window)
         if ret_filepath:
             if not ret_filepath.endswith(".pdf"): ret_filepath += ".pdf"
-            self.dad.pick_dir = os.path.dirname(ret_filepath)
+            self.dad.pick_dir_export = os.path.dirname(ret_filepath)
         return ret_filepath
 
     def nodes_all_export_print(self, top_tree_iter, include_node_name, new_node_in_new_page):
@@ -251,20 +298,20 @@ class Export2Txt:
         ret_filepath = support.dialog_file_save_as(proposed_name + ".txt",
                                                    filter_pattern="*.txt",
                                                    filter_name=_("Plain Text Document"),
-                                                   curr_folder=self.dad.pick_dir,
+                                                   curr_folder=self.dad.pick_dir_export,
                                                    parent=self.dad.window)
         if ret_filepath:
             if not ret_filepath.endswith(".txt"): ret_filepath += ".txt"
-            self.dad.pick_dir = os.path.dirname(ret_filepath)
+            self.dad.pick_dir_export = os.path.dirname(ret_filepath)
         return ret_filepath
 
-    def prepare_txt_folder(self, new_folder):
+    def prepare_txt_folder(self, new_folder, dir_place=""):
         """Prepare the website folder"""
-        dir_place = support.dialog_folder_select(curr_folder=self.dad.pick_dir, parent=self.dad.window)
-        if dir_place == None: return False
+        if not dir_place:
+            dir_place = support.dialog_folder_select(curr_folder=self.dad.pick_dir_export, parent=self.dad.window)
+            if dir_place == None: return False
         new_folder = support.clean_from_chars_not_for_filename(new_folder) + "_TXT"
-        while os.path.exists(os.path.join(dir_place, new_folder)):
-            new_folder += "2"
+        new_folder = prepare_export_folder(dir_place, new_folder, self.dad.export_overwrite)
         self.new_path = os.path.join(dir_place, new_folder)
         os.mkdir(self.new_path)
         return True
@@ -378,6 +425,7 @@ class Export2Txt:
             file_descriptor.close()
         return plain_text
 
+
 class Export2Pango:
     """The Export to Pango Class"""
 
@@ -529,14 +577,10 @@ class Export2Html:
     def prepare_html_folder(self, new_folder, dir_place=""):
         """Prepare the website folder"""
         if not dir_place:
-            dir_place = support.dialog_folder_select(curr_folder=self.dad.pick_dir, parent=self.dad.window)
+            dir_place = support.dialog_folder_select(curr_folder=self.dad.pick_dir_export, parent=self.dad.window)
             if dir_place == None: return False
         new_folder = support.clean_from_chars_not_for_filename(new_folder) + "_HTML"
-        if os.path.exists(os.path.join(dir_place, new_folder)):
-            n = 2
-            while os.path.exists(os.path.join(dir_place, new_folder + '%03d' % n)):
-                n += 1
-            new_folder += '%03d' % n
+        new_folder = prepare_export_folder(dir_place, new_folder, self.dad.export_overwrite)
         self.new_path = os.path.join(dir_place, new_folder)
         self.images_dir = os.path.join(self.new_path, "images")
         self.embed_dir = os.path.join(self.new_path, "EmbeddedFiles")
