@@ -2,7 +2,7 @@
 #
 #       menus.py
 #
-#       Copyright 2009-2016 Giuseppe Penone <giuspen@gmail.com>
+#       Copyright 2009-2017 Giuseppe Penone <giuspen@gmail.com>
 #
 #       This program is free software; you can redistribute it and/or modify
 #       it under the terms of the GNU General Public License as published by
@@ -30,9 +30,11 @@ CONFIG_ACTIONS_DICT = {
 "ct_new_inst",
 "ct_open_file",
 "ct_save",
+"ct_vacuum",
 "ct_save_as",
 "print_page_setup",
 "do_print",
+"exec_code",
 "quit_app",
 "exit_app",
 "preferences_dlg",
@@ -46,7 +48,6 @@ CONFIG_ACTIONS_DICT = {
 "tree_add_subnode",
 "tree_dup_node",
 "tree_node_date",
-"tree_node_new_father",
 "tree_all_sort_asc",
 "tree_all_sort_desc",
 "tree_sibl_sort_asc",
@@ -172,7 +173,9 @@ def load_menudict(dad):
 "ct_new_inst": {"sk": "new-instance", "sd": _("New _Instance"), "kb": None, "dn": _("Start a New Instance of CherryTree"), "cb": dad.file_new},
 "ct_open_file": {"sk": "gtk-open", "sd": _("_Open File"), "kb": KB_CONTROL+"O", "dn": _("Open a CherryTree Document"), "cb": dad.file_open},
 "ct_save": {"sk": "gtk-save", "sd": _("_Save"), "kb": KB_CONTROL+"S", "dn": _("Save File"), "cb": dad.file_save},
+"ct_vacuum": {"sk": "gtk-clear", "sd": _("Save and _Vacuum"), "kb": None, "dn": _("Save File and Vacuum"), "cb": dad.file_vacuum},
 "ct_save_as": {"sk": "gtk-save-as", "sd": _("Save _As"), "kb": KB_CONTROL+KB_SHIFT+"S", "dn": _("Save File As"), "cb": dad.file_save_as},
+"exec_code": {"sk": "gtk-execute", "sd": _("_Execute Code"), "kb": "F5", "dn": _("Execute Code"), "cb": dad.exec_code},
 "open_cfg_folder": {"sk": "gtk-directory", "sd": _("Open Preferences _Directory"), "kb": None, "dn": _("Open the Directory with Preferences Files"), "cb": dad.folder_cfg_open},
 "print_page_setup": {"sk": "gtk-print", "sd": _("Pa_ge Setup"), "kb": KB_CONTROL+KB_SHIFT+"P", "dn": _("Set up the Page for Printing"), "cb": dad.export_print_page_setup},
 "do_print": {"sk": "gtk-print", "sd": _("_Print"), "kb": KB_CONTROL+"P", "dn": _("Print"), "cb": dad.export_print},
@@ -229,14 +232,14 @@ def load_menudict(dad):
 "tree_add_subnode": {"sk": "tree-subnode-add", "sd": _("Add _SubNode"), "kb": KB_CONTROL+KB_SHIFT+"N", "dn": _("Add a Child Node to the Selected Node"), "cb": dad.node_child_add},
 "tree_dup_node": {"sk": "tree-node-dupl", "sd": _("_Duplicate Node"), "kb": KB_CONTROL+KB_SHIFT+"D", "dn": _("Duplicate the Selected Node"), "cb": dad.node_duplicate},
 "tree_node_prop": {"sk": "cherry_edit", "sd": _("Change Node _Properties"), "kb": "F2", "dn": _("Edit the Properties of the Selected Node"), "cb": dad.node_edit},
-"tree_node_toggle_ro": {"sk": "cherry_edit", "sd": _("Toggle _Read Only"), "kb": KB_CONTROL+KB_ALT+"R", "dn": _("Toggle the Read Only Property of the Selected Node"), "cb": dad.node_toggle_read_only},
+"tree_node_toggle_ro": {"sk": "locked", "sd": _("Toggle _Read Only"), "kb": KB_CONTROL+KB_ALT+"R", "dn": _("Toggle the Read Only Property of the Selected Node"), "cb": dad.node_toggle_read_only},
 "tree_node_date": {"sk": "calendar", "sd": _("Insert Today's Node"), "kb": "F8", "dn": _("Insert a Node with Hierarchy Year/Month/Day"), "cb": dad.node_date},
 "tree_parse_info": {"sk": "gtk-info", "sd": _("Tree _Info"), "kb": None, "dn": _("Tree Summary Information"), "cb": dad.tree_info},
 "tree_node_up": {"sk": "gtk-go-up", "sd": _("Node _Up"), "kb": KB_SHIFT+cons.STR_KEY_UP, "dn": _("Move the Selected Node Up"), "cb": dad.node_up},
 "tree_node_down": {"sk": "gtk-go-down", "sd": _("Node _Down"), "kb": KB_SHIFT+cons.STR_KEY_DOWN, "dn": _("Move the Selected Node Down"), "cb": dad.node_down},
 "tree_node_left": {"sk": "gtk-go-back", "sd": _("Node _Left"), "kb": KB_SHIFT+cons.STR_KEY_LEFT, "dn": _("Move the Selected Node Left"), "cb": dad.node_left},
 "tree_node_right": {"sk": "gtk-go-forward", "sd": _("Node _Right"), "kb": KB_SHIFT+cons.STR_KEY_RIGHT, "dn": _("Move the Selected Node Right"), "cb": dad.node_right},
-"tree_node_new_father": {"sk": "gtk-jump-to", "sd": _("Node Change _Parent"), "kb": None, "dn": _("Change the Selected Node's Parent"), "cb": dad.node_change_father},
+"tree_node_new_father": {"sk": "gtk-jump-to", "sd": _("Node Change _Parent"), "kb": KB_CONTROL+KB_SHIFT+cons.STR_KEY_RIGHT, "dn": _("Change the Selected Node's Parent"), "cb": dad.node_change_father},
 "tree_all_sort_asc": {"sk": "gtk-sort-ascending", "sd": _("Sort Tree _Ascending"), "kb": None, "dn": _("Sort the Tree Ascending"), "cb": dad.tree_sort_ascending},
 "tree_all_sort_desc": {"sk": "gtk-sort-descending", "sd": _("Sort Tree _Descending"), "kb": None, "dn": _("Sort the Tree Descending"), "cb": dad.tree_sort_descending},
 "tree_sibl_sort_asc": {"sk": "gtk-sort-ascending", "sd": _("Sort Siblings A_scending"), "kb": None, "dn": _("Sort all the Siblings of the Selected Node Ascending"), "cb": dad.node_siblings_sort_ascending},
@@ -245,17 +248,17 @@ def load_menudict(dad):
 "tree_node_del": {"sk": "edit-delete", "sd": _("De_lete Node"), "kb": "Delete", "dn": _("Delete the Selected Node"), "cb": dad.node_delete},
 "go_node_prev": {"sk": "gtk-go-back", "sd": _("Go _Back"), "kb": KB_ALT+cons.STR_KEY_LEFT, "dn": _("Go to the Previous Visited Node"), "cb": dad.go_back},
 "go_node_next": {"sk": "gtk-go-forward", "sd": _("Go _Forward"), "kb": KB_ALT+cons.STR_KEY_RIGHT, "dn": _("Go to the Next Visited Node"), "cb": dad.go_forward},
-"find_in_node": {"sk": "find", "sd": _("_Find in Node Content"), "kb": KB_CONTROL+"F", "dn": _("Find into the Selected Node Content"), "cb": dad.find_in_selected_node},
-"find_in_allnodes": {"sk": "find", "sd": _("Find in _All Nodes Contents"), "kb": KB_CONTROL+KB_SHIFT+"F", "dn": _("Find into All the Tree Nodes Contents"), "cb": dad.find_in_all_nodes},
-"find_in_node_n_sub": {"sk": "find", "sd": _("Find in _Selected Node and Subnodes Contents"), "kb": KB_CONTROL+KB_ALT+"F", "dn": _("Find into the Selected Node and Subnodes Contents"), "cb": dad.find_in_sel_node_and_subnodes},
+"find_in_node": {"sk": "find_sel", "sd": _("_Find in Node Content"), "kb": KB_CONTROL+"F", "dn": _("Find into the Selected Node Content"), "cb": dad.find_in_selected_node},
+"find_in_allnodes": {"sk": "find_all", "sd": _("Find in _All Nodes Contents"), "kb": KB_CONTROL+KB_SHIFT+"F", "dn": _("Find into All the Tree Nodes Contents"), "cb": dad.find_in_all_nodes},
+"find_in_node_n_sub": {"sk": "find_selnsub", "sd": _("Find in _Selected Node and Subnodes Contents"), "kb": KB_CONTROL+KB_ALT+"F", "dn": _("Find into the Selected Node and Subnodes Contents"), "cb": dad.find_in_sel_node_and_subnodes},
 "find_in_node_names": {"sk": "find", "sd": _("Find in _Nodes Names and Tags"), "kb": KB_CONTROL+"T", "dn": _("Find in Nodes Names and Tags"), "cb": dad.find_a_node},
 "find_iter_fw": {"sk": "find_again", "sd": _("Find _Again"), "kb": "F3", "dn": _("Iterate the Last Find Operation"), "cb": dad.find_again},
 "find_iter_bw": {"sk": "find_back", "sd": _("Find _Back"), "kb": "F4", "dn": _("Iterate the Last Find Operation in Opposite Direction"), "cb": dad.find_back},
-"replace_in_node": {"sk": "find_replace", "sd": _("_Replace in Node Content"), "kb": KB_CONTROL+"H", "dn": _("Replace into the Selected Node Content"), "cb": dad.replace_in_selected_node},
-"replace_in_allnodes": {"sk": "find_replace", "sd": _("Replace in _All Nodes Contents"), "kb": KB_CONTROL+KB_SHIFT+"H", "dn": _("Replace into All the Tree Nodes Contents"), "cb": dad.replace_in_all_nodes},
-"replace_in_node_n_sub": {"sk": "find_replace", "sd": _("Replace in _Selected Node and Subnodes Contents"), "kb": KB_CONTROL+KB_ALT+"H", "dn": _("Replace into the Selected Node and Subnodes Contents"), "cb": dad.replace_in_sel_node_and_subnodes},
+"replace_in_node": {"sk": "replace_sel", "sd": _("_Replace in Node Content"), "kb": KB_CONTROL+"H", "dn": _("Replace into the Selected Node Content"), "cb": dad.replace_in_selected_node},
+"replace_in_allnodes": {"sk": "replace_all", "sd": _("Replace in _All Nodes Contents"), "kb": KB_CONTROL+KB_SHIFT+"H", "dn": _("Replace into All the Tree Nodes Contents"), "cb": dad.replace_in_all_nodes},
+"replace_in_node_n_sub": {"sk": "replace_selnsub", "sd": _("Replace in _Selected Node and Subnodes Contents"), "kb": KB_CONTROL+KB_ALT+"H", "dn": _("Replace into the Selected Node and Subnodes Contents"), "cb": dad.replace_in_sel_node_and_subnodes},
 "replace_in_node_names": {"sk": "find_replace", "sd": _("Replace in Nodes _Names"), "kb": KB_CONTROL+KB_SHIFT+"T", "dn": _("Replace in Nodes Names"), "cb": dad.replace_in_nodes_names},
-"replace_iter_fw": {"sk": "find_replace", "sd": _("Replace _Again"), "kb": "F6", "dn": _("Iterate the Last Replace Operation"), "cb": dad.replace_again},
+"replace_iter_fw": {"sk": "replace_again", "sd": _("Replace _Again"), "kb": "F6", "dn": _("Iterate the Last Replace Operation"), "cb": dad.replace_again},
 "toggle_show_tree": {"sk": "cherries", "sd": _("Show/Hide _Tree"), "kb": "F9", "dn": _("Toggle Show/Hide Tree"), "cb": dad.toggle_show_hide_tree},
 "toggle_show_toolbar": {"sk": "toolbar", "sd": _("Show/Hide Tool_bar"), "kb": None, "dn": _("Toggle Show/Hide Toolbar"), "cb": dad.toggle_show_hide_toolbar},
 "toggle_show_node_name_head": {"sk": "node_name_header", "sd": _("Show/Hide Node Name _Header"), "kb": None, "dn": _("Toggle Show/Hide Node Name Header"), "cb": dad.toggle_show_hide_node_name_header},
@@ -533,6 +536,7 @@ def get_popup_menu_entries_code(dad):
     # "submenu-end", None, None, None, None
     return [
 (cons.TAG_SEPARATOR, None, None, None, None),
+get_menu_item_tuple(dad, "exec_code"),
 ("submenu-start", _("_Insert") , "insert", None, None),
 get_menu_item_tuple(dad, "insert_timestamp"),
 get_menu_item_tuple(dad, "insert_horiz_rule"),
@@ -631,6 +635,7 @@ def get_popup_menu_entries_codebox(dad):
     return [
 (cons.TAG_SEPARATOR, None, None, None, None),
 ("codebox_edit", _("Change CodeBox _Properties"), None, _("Edit the Properties of the CodeBox"), dad.codebox_change_properties),
+("gtk-execute", _("_Execute CodeBox Code"), None, _("Execute CodeBox Code"), dad.dad.exec_code),
 ("from_txt", _("CodeBox _Load From Text File"), None, _("Load the CodeBox Content From a Text File"), dad.codebox_load_from_file),
 ("to_txt", _("CodeBox _Save To Text File"), None, _("Save the CodeBox Content To a Text File"), dad.codebox_save_to_file),
 (cons.TAG_SEPARATOR, None, None, None, None),
@@ -652,12 +657,15 @@ UI_INFO = """
       <menuitem action='ct_new_inst'/>
       <menuitem action='ct_open_file'/>
       <separator/>
+      <menuitem action='ct_vacuum'/>
       <menuitem action='ct_save'/>
       <menuitem action='ct_save_as'/>
       <separator/>
       <menuitem action='print_page_setup'/>
       <menuitem action='do_print'/>
       <separator/>
+      <menuitem action='exec_code'/>
+      <separator/>
       <menuitem action='quit_app'/>
       <menuitem action='exit_app'/>
     </menu>
